<?php

declare(strict_types = 1);

namespace Drupal\search_web_components_block\Plugin\Block;

use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a search component: facet dropdown html.
 *
 * @Block(
 *   id = "swc_facet_dropdown_html",
 *   admin_label = @Translation("Facet: Dropdown HTML"),
 *   category = @Translation("Search Components"),
 * )
 */
final class FacetDropdownHtmlBlock extends FacetBlockBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration(): array {
    return parent::defaultConfiguration() + [
      'required' => FALSE,
      'htmlSelectLabel' => '',
      'multipleSelect' => FALSE,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state): array {
    $form = parent::blockForm($form, $form_state);
    $form['htmlSelectLabel'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Select label'),
      '#description' => $this->t('The label text to display inside the select box.'),
      '#default_value' => $this->configuration['htmlSelectLabel'],
    ];
    $form['required'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Required'),
      '#description' => 'When checked a user will have to choose a value for this field.',
      '#default_value' => $this->configuration['required'],
    ];
    $form['multipleSelect'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Allow selecting multiple values'),
      '#default_value' => $this->configuration['multipleSelect'],
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state): void {
    parent::blockSubmit($form, $form_state);
    $this->configuration['htmlSelectLabel'] = $form_state->getValue('htmlSelectLabel');
    $this->configuration['required'] = $form_state->getValue('required');
    $this->configuration['multipleSelect'] = $form_state->getValue('multipleSelect');
  }

  /**
   * {@inheritdoc}
   */
  public function build(): array {
    $build = parent::build();
    $build['#theme'] = 'swc_facet_dropdown_html';
    $build['#htmlSelectLabel'] = $this->configuration['htmlSelectLabel'];
    $build['#required'] = $this->configuration['required'];
    $build['#multipleSelect'] = $this->configuration['multipleSelect'];

    return $build;
  }

}
