<?php

declare(strict_types = 1);

namespace Drupal\search_web_components_block\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a search component: results per page block.
 *
 * @Block(
 *   id = "swc_search_results_per_page",
 *   admin_label = @Translation("Results per page"),
 *   category = @Translation("Search Components"),
 * )
 */
final class SearchResultsPerPageBlock extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration(): array {
    return [
      'type' => 'select',
      'labelText' => 'Per page',
      'options' => '[{"key": "10","label": "10"}]',
      'htmlSelectLabel' => 'Per page',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state): array {
    $form['type'] = [
      '#type' => 'select',
      '#title' => $this->t('Display as'),
      '#default_value' => $this->configuration['type'],
      '#options' => ['select' => 'select', 'list' => 'list', 'html' => 'html'],
      '#required' => TRUE,
    ];
    $form['labelText'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Label text'),
      '#default_value' => $this->configuration['labelText'],
    ];
    $form['options'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Available options'),
      '#description' => $this->t('A JSON array of objects with properties key and label. [{"key":"10","label":"10"},{"key":"20","label":"20"},{"key":"50","label":"50"}]. Tools like <a href="https://jsonformatter.org/" target="_blank">https://jsonformatter.org/</a>a can help validate your JSON.'),
      '#default_value' => $this->configuration['options'],
    ];
    $form['htmlSelectLabel'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Html select label'),
      '#description' => $this->t('The label text to display inside an HTML select'),
      '#default_value' => $this->configuration['htmlSelectLabel'],
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state): void {
    $this->configuration['type'] = $form_state->getValue('type');
    $this->configuration['labelText'] = $form_state->getValue('labelText');
    $this->configuration['options'] = $form_state->getValue('options');
    $this->configuration['htmlSelectLabel'] = $form_state->getValue('htmlSelectLabel');
  }

  /**
   * {@inheritdoc}
   */
  public function build(): array {
    return [
      '#theme' => 'swc_search_results_per_page',
      '#type' => $this->configuration['type'],
      '#labelText' => $this->configuration['labelText'],
      '#options' => $this->configuration['options'],
      '#htmlSelectLabel' => $this->configuration['htmlSelectLabel'],
      '#attached' => [
        'library' => [
          'search_web_components/components',
        ],
      ],
    ];
  }

}
