<?php

declare(strict_types = 1);

namespace Drupal\search_web_components_block\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a search component: results display switcher block.
 *
 * @Block(
 *   id = "swc_search_results_switcher",
 *   admin_label = @Translation("Results display switcher"),
 *   category = @Translation("Search Components"),
 * )
 */
final class SearchResultsSwitcher extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration(): array {
    return [
      'options' => '[{"key": "List","label": "List"}]',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state): array {
    $form['options'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Available options'),
      '#description' => $this->t('A JSON array of objects with properties key and label. [{"key":"list","label":"list"},{"key":"grid","label":"grid"}]. Tools like <a href="https://jsonformatter.org/" target="_blank">https://jsonformatter.org/</a>a can help validate your JSON.'),
      '#default_value' => $this->configuration['options'],
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state): void {
    $this->configuration['options'] = $form_state->getValue('options');
  }

  /**
   * {@inheritdoc}
   */
  public function build(): array {
    return [
      '#theme' => 'swc_search_results_switcher',
      '#options' => $this->configuration['options'],
      '#attached' => [
        'library' => [
          'search_web_components/components',
        ],
      ],
    ];
  }

}
