<?php

declare(strict_types = 1);

namespace Drupal\search_web_components_block\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a search component: sort block.
 *
 * @Block(
 *   id = "swc_search_sort",
 *   admin_label = @Translation("Sort"),
 *   category = @Translation("Search Components"),
 * )
 */
final class SearchSortBlock extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration(): array {
    return [
      'type' => 'select',
      'labelText' => 'Sort by',
      'sorts' => '[{"key": "search_api_relevance","label": "Relevance","order": "desc"}]',
      'htmlSelectLabel' => 'Sort by',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state): array {
    $form['type'] = [
      '#type' => 'select',
      '#title' => $this->t('Display as'),
      '#default_value' => $this->configuration['type'],
      '#options' => ['select' => 'select', 'list' => 'list', 'html' => 'html'],
      '#required' => TRUE,
    ];
    $form['labelText'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Label'),
      '#default_value' => $this->configuration['labelText'],
    ];
    $form['sorts'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Available sorts'),
      '#description' => $this->t('A JSON array of sort options structured like [{"key": "example_field", "label": "Example", "order": "asc or desc"}]. Tools like <a href="https://jsonformatter.org/" target="_blank">https://jsonformatter.org/</a>a can help validate your JSON.'),
      '#default_value' => $this->configuration['sorts'],
    ];
    $form['htmlSelectLabel'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Html select label'),
      '#description' => $this->t('The label text to display inside an HTML select'),
      '#default_value' => $this->configuration['htmlSelectLabel'],
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state): void {
    $this->configuration['type'] = $form_state->getValue('type');
    $this->configuration['labelText'] = $form_state->getValue('labelText');
    $this->configuration['sorts'] = $form_state->getValue('sorts');
    $this->configuration['htmlSelectLabel'] = $form_state->getValue('htmlSelectLabel');
  }

  /**
   * {@inheritdoc}
   */
  public function build(): array {
    return [
      '#theme' => 'swc_search_sort',
      '#type' => $this->configuration['type'],
      '#labelText' => $this->configuration['labelText'],
      '#sorts' => $this->configuration['sorts'],
      '#htmlSelectLabel' => $this->configuration['htmlSelectLabel'],
      '#attached' => [
        'library' => [
          'search_web_components/components',
        ],
      ],
    ];
  }

}
